@@ -182,10 +182,14 @@ class OsWalker(object):
         return self
         
     def clearResultMemory(self):
-        OsDebug.tmpfile.memory = []
+        if OsDebug.tmpfile:
+            OsDebug.tmpfile.clearMemory()
     
     def result(self):
-        return '\r\n'.join(OsDebug.tmpfile.memory)
+        if OsDebug.tmpfile:
+            return '\r\n'.join(OsDebug.tmpfile.getMemory())
+        else:
+            return ''
         
     def resultLines(self):
         return [a.replace('\n','') for a in self.result().split('\r\n') if len(a.replace('\n','')) and self.lastCommand != a and not '#' in a]
